@@ -8,7 +8,6 @@ import (
 	"oss.terrastruct.com/d2/d2layouts/d2dagrelayout"
 	"oss.terrastruct.com/d2/d2lib"
 	"oss.terrastruct.com/d2/d2oracle"
-	"oss.terrastruct.com/d2/d2themes/d2themescatalog"
 	"oss.terrastruct.com/d2/lib/textmeasure"
 )
 
@@ -17,9 +16,8 @@ func main() {
 	// From one.go
 	ruler, _ := textmeasure.NewRuler()
 	_, graph, _ := d2lib.Compile(context.Background(), "x -> y", &d2lib.CompileOptions{
-		Layout:  d2dagrelayout.DefaultLayout,
-		Ruler:   ruler,
-		ThemeID: d2themescatalog.GrapeSoda.ID,
+		Layout: d2dagrelayout.DefaultLayout,
+		Ruler:  ruler,
 	})
 
 	// Create a shape with the ID, "meow"
