@@ -17,12 +17,14 @@ import (
 // Remember to add if err != nil checks in production.
 func main() {
 	graph, _ := d2compiler.Compile("", strings.NewReader("x -> y"), nil)
+	graph.ApplyTheme(d2themescatalog.NeutralDefault.ID)
 	ruler, _ := textmeasure.NewRuler()
 	_ = graph.SetDimensions(nil, ruler, nil)
 	_ = d2dagrelayout.Layout(context.Background(), graph, nil)
-	diagram, _ := d2exporter.Export(context.Background(), graph, d2themescatalog.NeutralDefault.ID, nil)
+	diagram, _ := d2exporter.Export(context.Background(), graph, nil)
 	out, _ := d2svg.Render(diagram, &d2svg.RenderOpts{
-		Pad: d2svg.DEFAULT_PADDING,
+		Pad:     d2svg.DEFAULT_PADDING,
+		ThemeID: d2themescatalog.NeutralDefault.ID,
 	})
 	_ = ioutil.WriteFile(filepath.Join("out.svg"), out, 0600)
 }
